Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(15)

Unified Diff: editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/source/FileBasedSource.java

Issue 11745013: Rename two classes (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/source/FileBasedSource.java
===================================================================
--- editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/source/FileBasedSource.java (revision 16603)
+++ editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/source/FileBasedSource.java (working copy)
@@ -21,9 +21,9 @@
import java.nio.charset.Charset;
/**
* Instances of the class {@code SourceImpl} implement a basic source object.
*/
-public class SourceImpl implements Source {
+public class FileBasedSource implements Source {
/**
* The source factory that created this source and that should be used to resolve URI's against
* this source.
@@ -52,7 +52,7 @@
* @param factory the source factory that created this source
* @param file the file represented by this source
*/
- public SourceImpl(SourceFactory factory, File file) {
+ public FileBasedSource(SourceFactory factory, File file) {
this(factory, file, false);
}
@@ -63,7 +63,7 @@
* @param file the file represented by this source
* @param inSystemLibrary {@code true} if this source is in one of the system libraries
*/
- public SourceImpl(SourceFactory factory, File file, boolean inSystemLibrary) {
+ public FileBasedSource(SourceFactory factory, File file, boolean inSystemLibrary) {
this.factory = factory;
this.file = file;
this.inSystemLibrary = inSystemLibrary;
@@ -71,7 +71,7 @@
@Override
public boolean equals(Object object) {
- return this.getClass() == object.getClass() && file.equals(((SourceImpl) object).file);
+ return this.getClass() == object.getClass() && file.equals(((FileBasedSource) object).file);
}
@Override

Powered by Google App Engine
This is Rietveld 408576698
@@ -21,9 +21,9 @@
import java.nio.charset.Charset;
/**
- * Instances of the class {@code SourceImpl} implement a basic source object.
+ * Instances of the class {@code FileBasedSource} implement a source that represents a file.
*/